interceptorschain

package
v0.0.0-...-c419df0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 12, 2026 License: GPL-3.0 Imports: 2 Imported by: 0

Documentation

Overview

Package interceptorschain allows chaining multiple streams server interceptor by returning an unique interceptor.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func StreamClient

func StreamClient(interceptors ...grpc.StreamClientInterceptor) grpc.StreamClientInterceptor

StreamClient creates a single interceptor out of a chain of many interceptors.

func StreamServer

func StreamServer(interceptors ...grpc.StreamServerInterceptor) grpc.StreamServerInterceptor

StreamServer allows chaining multiple streams server interceptor by returning an unique interceptor.

Types

This section is empty.

Jump to