doc

package
v0.0.0-...-426bf0d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 26, 2024 License: GPL-3.0 Imports: 2 Imported by: 1

Documentation

Overview

Package doc is a helper sub-module so that the documentation generation tools have access to the commands to document in this module.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Commands

func Commands() []cobra.Command

Commands returns the commands we want to generate documentation for.

Types

This section is empty.

Jump to