Documentation
¶
Overview ¶
Package interceptorschain allows chaining multiple streams server interceptor by returning an unique interceptor.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func StreamClient ¶
func StreamClient(interceptors ...grpc.StreamClientInterceptor) grpc.StreamClientInterceptor
StreamClient creates a single interceptor out of a chain of many interceptors.
func StreamServer ¶
func StreamServer(interceptors ...grpc.StreamServerInterceptor) grpc.StreamServerInterceptor
StreamServer allows chaining multiple streams server interceptor by returning an unique interceptor.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.