Documentation
¶
Overview ¶
Package logconnections implements a stream interceptor to notify the pinged object on each new and ended connections.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func StreamServerInterceptor ¶
func StreamServerInterceptor() func(srv interface{}, ss grpc.ServerStream, info *grpc.StreamServerInfo, handler grpc.StreamHandler) error
StreamServerInterceptor notifies the pingued object on each new and ended connections. If the pingued object implements onNewConnectionner, it will have OnNewConnection called when the connection is established (can be used for logging for instance) If the pingued object implements onDoneConnectionner, it will have OnDoneConnection called when the connection was handled by the server (can be used to reset an internal timeout for instance).
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.