Documentation
¶
Overview ¶
Package test contains the log test generated struct for logstreamer package tests.
This is a separate package to not embed that structure in the finale binary.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var File_log_test_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type EmptyLogTest ¶
type EmptyLogTest struct {
// contains filtered or unexported fields
}
this is the base object to decode into for client tests, including log messages that are later turned as Log object.
func (*EmptyLogTest) Descriptor
deprecated
func (*EmptyLogTest) Descriptor() ([]byte, []int)
Deprecated: Use EmptyLogTest.ProtoReflect.Descriptor instead.
func (*EmptyLogTest) ProtoMessage ¶
func (*EmptyLogTest) ProtoMessage()
func (*EmptyLogTest) ProtoReflect ¶
func (x *EmptyLogTest) ProtoReflect() protoreflect.Message
func (*EmptyLogTest) Reset ¶
func (x *EmptyLogTest) Reset()
func (*EmptyLogTest) String ¶
func (x *EmptyLogTest) String() string
Click to show internal directories.
Click to hide internal directories.