Documentation
¶
Overview ¶
Package microsoftstore is a wrapper around storeapi.dll
Package microsoftstore is a stump to allow the project to build on Linux.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateUserJWT ¶
GenerateUserJWT takes an azure AD server access token and returns a Windows store token.
func GetSubscriptionExpirationDate ¶
GetSubscriptionExpirationDate returns the expiration date for the current subscription.
func NewStoreAPIError ¶
NewStoreAPIError creates StoreAPIError from the result of a call to the storeAPI DLL.
Types ¶
type StoreAPIError ¶
type StoreAPIError int64
StoreAPIError are the error constants in the store api.
const ( ErrNotSubscribed StoreAPIError = iota - 128 ErrNoProductsFound ErrTooManyProductsFound ErrInvalidUserInfo ErrNoLocalUser ErrTooManyLocalUsers ErrEmptyJwt ErrAllocationFailure StoreAPIError = -10 ErrNullInputPtr StoreAPIError = -9 ErrTooBigLength StoreAPIError = -8 ErrZeroLength StoreAPIError = -7 ErrNullOutputPtr StoreAPIError = -6 ErrStoreAPI StoreAPIError = -3 ErrWinRT StoreAPIError = -2 ErrUnknown StoreAPIError = -1 ErrSuccess StoreAPIError = 0 )
Keep up-to-date with `storeapi\base\Exception.hpp`.
func (StoreAPIError) Error ¶
func (err StoreAPIError) Error() string
Click to show internal directories.
Click to hide internal directories.