Documentation
¶
Overview ¶
Package wslserviceapi allows generated API bindings from GRPC definitions.
Index ¶
- Constants
- Variables
- func RegisterWSLServer(s grpc.ServiceRegistrar, srv WSLServer)
- type Empty
- type LandscapeConfig
- func (*LandscapeConfig) Descriptor() ([]byte, []int)deprecated
- func (x *LandscapeConfig) GetConfiguration() string
- func (x *LandscapeConfig) GetHostagentUID() string
- func (*LandscapeConfig) ProtoMessage()
- func (x *LandscapeConfig) ProtoReflect() protoreflect.Message
- func (x *LandscapeConfig) Reset()
- func (x *LandscapeConfig) String() string
- type ProAttachInfo
- type UnimplementedWSLServer
- type UnsafeWSLServer
- type WSLClient
- type WSLServer
Constants ¶
const ( WSL_ApplyProToken_FullMethodName = "/wslserviceapi.WSL/ApplyProToken" WSL_Ping_FullMethodName = "/wslserviceapi.WSL/Ping" WSL_ApplyLandscapeConfig_FullMethodName = "/wslserviceapi.WSL/ApplyLandscapeConfig" )
Variables ¶
var File_wslserviceapi_proto protoreflect.FileDescriptor
var WSL_ServiceDesc = grpc.ServiceDesc{ ServiceName: "wslserviceapi.WSL", HandlerType: (*WSLServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ApplyProToken", Handler: _WSL_ApplyProToken_Handler, }, { MethodName: "Ping", Handler: _WSL_Ping_Handler, }, { MethodName: "ApplyLandscapeConfig", Handler: _WSL_ApplyLandscapeConfig_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "wslserviceapi.proto", }
WSL_ServiceDesc is the grpc.ServiceDesc for WSL service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterWSLServer ¶
func RegisterWSLServer(s grpc.ServiceRegistrar, srv WSLServer)
Types ¶
type Empty ¶
type Empty struct {
// contains filtered or unexported fields
}
func (*Empty) Descriptor
deprecated
func (*Empty) ProtoMessage ¶
func (*Empty) ProtoMessage()
func (*Empty) ProtoReflect ¶
func (x *Empty) ProtoReflect() protoreflect.Message
type LandscapeConfig ¶
type LandscapeConfig struct {
// Empty configuration is interpreted as "landscape-config --disable"
Configuration string `protobuf:"bytes,1,opt,name=configuration,proto3" json:"configuration,omitempty"`
HostagentUID string `protobuf:"bytes,2,opt,name=hostagentUID,proto3" json:"hostagentUID,omitempty"`
// contains filtered or unexported fields
}
func (*LandscapeConfig) Descriptor
deprecated
func (*LandscapeConfig) Descriptor() ([]byte, []int)
Deprecated: Use LandscapeConfig.ProtoReflect.Descriptor instead.
func (*LandscapeConfig) GetConfiguration ¶
func (x *LandscapeConfig) GetConfiguration() string
func (*LandscapeConfig) GetHostagentUID ¶
func (x *LandscapeConfig) GetHostagentUID() string
func (*LandscapeConfig) ProtoMessage ¶
func (*LandscapeConfig) ProtoMessage()
func (*LandscapeConfig) ProtoReflect ¶
func (x *LandscapeConfig) ProtoReflect() protoreflect.Message
func (*LandscapeConfig) Reset ¶
func (x *LandscapeConfig) Reset()
func (*LandscapeConfig) String ¶
func (x *LandscapeConfig) String() string
type ProAttachInfo ¶
type ProAttachInfo struct {
// Empty token is interpreted as "pro detach"
Token string `protobuf:"bytes,1,opt,name=token,proto3" json:"token,omitempty"`
// contains filtered or unexported fields
}
func (*ProAttachInfo) Descriptor
deprecated
func (*ProAttachInfo) Descriptor() ([]byte, []int)
Deprecated: Use ProAttachInfo.ProtoReflect.Descriptor instead.
func (*ProAttachInfo) GetToken ¶
func (x *ProAttachInfo) GetToken() string
func (*ProAttachInfo) ProtoMessage ¶
func (*ProAttachInfo) ProtoMessage()
func (*ProAttachInfo) ProtoReflect ¶
func (x *ProAttachInfo) ProtoReflect() protoreflect.Message
func (*ProAttachInfo) Reset ¶
func (x *ProAttachInfo) Reset()
func (*ProAttachInfo) String ¶
func (x *ProAttachInfo) String() string
type UnimplementedWSLServer ¶
type UnimplementedWSLServer struct {
}
UnimplementedWSLServer must be embedded to have forward compatible implementations.
func (UnimplementedWSLServer) ApplyLandscapeConfig ¶
func (UnimplementedWSLServer) ApplyLandscapeConfig(context.Context, *LandscapeConfig) (*Empty, error)
func (UnimplementedWSLServer) ApplyProToken ¶
func (UnimplementedWSLServer) ApplyProToken(context.Context, *ProAttachInfo) (*Empty, error)
type UnsafeWSLServer ¶
type UnsafeWSLServer interface {
// contains filtered or unexported methods
}
UnsafeWSLServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to WSLServer will result in compilation errors.
type WSLClient ¶
type WSLClient interface {
ApplyProToken(ctx context.Context, in *ProAttachInfo, opts ...grpc.CallOption) (*Empty, error)
Ping(ctx context.Context, in *Empty, opts ...grpc.CallOption) (*Empty, error)
ApplyLandscapeConfig(ctx context.Context, in *LandscapeConfig, opts ...grpc.CallOption) (*Empty, error)
}
WSLClient is the client API for WSL service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewWSLClient ¶
func NewWSLClient(cc grpc.ClientConnInterface) WSLClient
type WSLServer ¶
type WSLServer interface {
ApplyProToken(context.Context, *ProAttachInfo) (*Empty, error)
Ping(context.Context, *Empty) (*Empty, error)
ApplyLandscapeConfig(context.Context, *LandscapeConfig) (*Empty, error)
// contains filtered or unexported methods
}
WSLServer is the server API for WSL service. All implementations must embed UnimplementedWSLServer for forward compatibility